@@ -13,10 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import io
 import sys
 
 import requests
-import six
 import testtools
 
 from glanceclient.common import progressbar
@@ -49,7 +49,7 @@ class TestProgressBarWrapper(testtools.TestCase):
 
     def test_iter_file_display_progress_bar(self):
         size = 98304
-        file_obj = six.StringIO('X' * size)
+        file_obj = io.StringIO('X' * size)
         saved_stdout = sys.stdout
         try:
             sys.stdout = output = test_utils.FakeTTYStdout()
@@ -67,7 +67,7 @@ class TestProgressBarWrapper(testtools.TestCase):
 
     def test_iter_file_no_tty(self):
         size = 98304
-        file_obj = six.StringIO('X' * size)
+        file_obj = io.StringIO('X' * size)
         saved_stdout = sys.stdout
         try:
             sys.stdout = output = test_utils.FakeNoTTYStdout()
